<?php

class ESysLogRoute extends CLogRoute
{

	/**
	 * @var array levels
	 */
	public $levels;

	/**
	 * @var array categories
	 */
	public $categories;

	/**
	 * @var string logName
	 */
	private $_logName;

	/**
	 * @var string logFacility
	 */
	private $_logFacility;

	/**
	 * Initializes the route.
	 * This method is invoked after the route is created by the route manager.
	 */
	public function init()
	{
		parent::init();
		$this->setLogName(Yii::app()->params['logName']);
		if( null === $this->getLogName() )
			$this->setLogName('YiiApp');
		
		$this->setLogFacility(Yii::app()->params['logFacility']);
		if( null === $this->getLogFacility() )
			$this->setLogFacility(LOG_LOCAL0);

		openlog($this->getLogName(), LOG_NDELAY, $this->getLogFacility());
	}

	/**
	 * @return string _logName used for identifying our log messages.
	 */
	public function getLogName()
	{
		return $this->_logName;
	}

	/**
	 * @param string logname used for identifying our log messages.
	 */
	public function setLogName($logname)
	{
		$this->_logName = $logname;
	}

	/**
	 * @return string _logFacility used for syslog facility selection.
	 */
	public function getLogFacility()
	{
		return $this->_logFacility;
	}

	/**
	 * @param string logfacility used for syslog facility selection.
	 */
	public function setLogFacility($logfacility)
	{
		$this->_logFacility = $logfacility;
	}

	/**
	 * Saves log messages in files.
	 * @param array list of log messages
	 */
	protected function processLogs($logs)
	{
		foreach($logs as $log) {
			switch($log[1]) {
				case 'trace':
					$pri = LOG_DEBUG;
				case 'info':
					$pri = LOG_INFO;
				case 'profile':
					$pri = LOG_NOTICE;
				case 'warning':
					$pri = LOG_WARNING;
				case 'error':
					$pri = LOG_ERR;
			}
			syslog($pri, $log[1] . ' - (' . $log[2] . ') - ' . $log[0]);
		}

		closelog();
	}

}
